.. sumo-experiments documentation master file, created by
   sphinx-quickstart on Thu Mar 27 09:49:35 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sumo-experiments's documentation!
============================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:
   
   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
